@@ -7,24 +7,21 @@ from loguru import logger
 from . import GeneralConstants
 from .chat import Chat
 from .chat_configs import ChatOptions
+from .openai_utils import CannotConnectToApiError
+from .voice_chat import VoiceChat
 
 
-def accounting(args):
-    """Show the accumulated costs of the chat and exit."""
-    chat = Chat.from_cli_args(cli_args=args)
-    chat.private_mode = True
-    chat.report_token_usage(current_chat=False)
-
-
-def run_on_terminal(args):
+def voice_chat(args):
     """Run the chat on the terminal."""
-    chat = Chat.from_cli_args(cli_args=args)
-    chat.start()
-    if args.report_accounting_when_done:
-        chat.report_token_usage(current_chat=True)
+    chat = VoiceChat.from_cli_args(cli_args=args)
+    try:
+        chat.start()
+    except CannotConnectToApiError as error:
+        logger.error("API connection problems: {}\nExiting.", error)
+        raise SystemExit(1) from error
 
 
-def run_on_ui(args):
+def browser_chat(args):
     """Run the chat on the browser."""
     ChatOptions.from_cli_args(args).export(fpath=GeneralConstants.PARSED_ARGS_FILE)
     try:
@@ -41,3 +38,19 @@ def run_on_ui(args):
         )
     except (KeyboardInterrupt, EOFError):
         logger.info("Exiting.")
+
+
+def terminal_chat(args):
+    """Run the chat on the terminal."""
+    chat = Chat.from_cli_args(cli_args=args)
+    chat.start()
+    if args.report_accounting_when_done:
+        chat.report_token_usage(report_general=True)
+
+
+def accounting_report(args):
+    """Show the accumulated costs of the chat and exit."""
+    chat = Chat.from_cli_args(cli_args=args)
+    # Prevent chat from creating entry in the cache directory
+    chat.private_mode = True
+    chat.report_token_usage(report_general=True, report_current_chat=False)
